@@ -338,6 +338,9 @@ class JSONRenderer(BaseRenderer):
             "tags": pnl_tags,
             "width_ratios": pnl.width_ratios,
             "height_ratios": pnl.height_ratios,
+            "x_stretch": pnl.x_stretch,
+            "y_stretch": pnl.y_stretch,
+            "right_subplot": pnl.right_subplot,
             "grid_x": pnl._x,
             "grid_y": pnl._y,
         }
